@@ -27,6 +27,7 @@ from .utils import decode_message
 import requests
 import datetime
 import json
+import zlib
 
 __all__ = ["DataClient"]
 
@@ -36,6 +37,15 @@ def to_upper(v):
     return v.upper() if isinstance(v, str) else v
 
 
+# -----------------------------------------------------------------------------
+def get_payload(response):
+    payload = response["payload"]
+    if request.get("compressed", False):
+        return json.loads(zlib.decompress(payload))
+    else:
+        return payload
+
+
 ###############################################################################
 class DataClient(object):
     """
@@ -58,6 +68,7 @@ class DataClient(object):
         field,
         overrides=None,
         RT=False,
+        compress=False,
         fail_after=5
     ):
         # --- ensure security, field, and overrides are upper case as the
@@ -82,11 +93,12 @@ class DataClient(object):
             "field": field,
             "overrides": overrides,
             "rt": RT,
+            "compress": compress,
             "type": "BDP",
         }
 
         response = self.query(self.bdp_url, request, fail_after)
-        return response["payload"]
+        return get_payload(response)
 
     # -------------------------------------------------------------------------
     def BDH(
@@ -97,6 +109,7 @@ class DataClient(object):
         ed,
         adj=True,
         overrides=None,
+        compress=True,
         fail_after=5
     ):
         # --- ensure security, field, and overrides are upper case as the
@@ -123,15 +136,16 @@ class DataClient(object):
             "end": ed.strftime("%Y%m%d"),
             "adjusted": adj,
             "overrides": overrides,
+            "compress": compress,
             "type": "BDH",
         }
 
         response = self.query(self.bdh_url, request, fail_after)
 
         if response["type"] == "Curve":
-            return CurveField.from_json(None, response["payload"])
+            return CurveField.from_json(None, get_payload(response))
         elif response["type"] == "HlocvCurve":
-            return HlocvCurveField.from_json(None, response["payload"])
+            return HlocvCurveField.from_json(None, get_payload(response))
 
     # -------------------------------------------------------------------------
     def HDP(self, sec, field, date, overrides=None):
@@ -171,14 +185,14 @@ class DataClient(object):
     # -------------------------------------------------------------------------
     def manage_exceptions(self, response):
         if response["type"] == "TimeoutError":
-            raise TimeoutError(response["payload"])
+            raise TimeoutError(get_payload(response))
         if response["type"] == "NoDataserverAvailable":
-            raise NoDataserverAvailable(response["payload"])
+            raise NoDataserverAvailable(get_payload(response))
         if response["type"] == "DatafeedError":
-            raise DatafeedError(response["payload"])
+            raise DatafeedError(get_payload(response))
         if response["type"] == "SecurityError":
-            raise SecurityError(response["payload"])
+            raise SecurityError(get_payload(response))
         if response["type"] == "FieldError":
-            raise FieldError(response["payload"])
+            raise FieldError(get_payload(response))
         if response["type"] == "NotImplementedError":
-            raise NotImplementedError(response["payload"])
+            raise NotImplementedError(get_payload(response))
