@@ -35,6 +35,7 @@ import tornado.netutil
 
 import time
 import json
+import zlib
 import datetime
 import socket
 import urllib
@@ -86,14 +87,20 @@ def bdh_request(timeout, request):
 
 
 # -----------------------------------------------------------------------------
-def process_response(resp):
+def process_response(resp, compress):
     dtype = resp["type"]
     if dtype == "Curve":
         resp["payload"] = CurveField.to_json(None, resp["payload"])
     elif dtype == "HlocvCurve":
         resp["payload"] = HlocvCurveField.to_json(None, resp["payload"])
     elif dtype == "GCurve":
-        resp["payload"] = GCurveField.to_json(None, resp["payload"])
+        resp["payload"] = GCurveFied.to_json(None, resp["payload"])
+
+    if compress:
+        payload = json.dumps(resp["payload"]), separators=(",", ":")) + "\n"
+        resp["payload"] = zlib.compress(bytes(payload, "utf-8"))
+        resp["compressed"] = True
+
     return resp
 
 
@@ -229,6 +236,7 @@ class DataServer(tornado.tcpserver.TCPServer):
         self.logger.debug(f"processing request {request!s}")
 
         request_type = request.pop("type")
+        compress = request.pop("compress", False)
 
         # --- overrides, which are sent by clients as json strings, are decoded
         #     here 'in-place'
@@ -252,11 +260,9 @@ class DataServer(tornado.tcpserver.TCPServer):
                 "type": "TimeoutError",
                 "payload": err_msg
             }
-            # --- for bdp request, try re-initializing client
-            if request_type == "BDP":
-                clt.stop()
-                clt.initialize_session_and_service()
- 
+            # --- try re-initializing client
+            clt.stop()
+            clt.initialize_session_and_service()
         except DatafeedFatal as err:
             # --- unrecoverable bloomberg error: don't send a reply so that
             #     the datafeed router knows this server is currently unable
@@ -264,7 +270,7 @@ class DataServer(tornado.tcpserver.TCPServer):
             self.logger.error(err, exc_info=True)
             return
 
-        resp = process_response(resp)
+        resp = process_response(resp, compress)
         resp = encode_message(resp)
 
         try:
